@@ -49,55 +49,6 @@ get_cnlist <- function(CopyNumber, ignore_chrs = NULL, add_index = FALSE) {
 
 # Get feature distributions -----------------------------------------------
 
-get_features <- function(CN_data,
-                         cores = 1,
-                         genome_build = c("hg19", "hg38", "mm10")) {
-  genome_build <- match.arg(genome_build)
-  # get chromosome lengths and centromere locations
-  chrlen <- get_genome_annotation(data_type = "chr_size", genome_build = genome_build)
-  centromeres <- get_genome_annotation(data_type = "centro_loc", genome_build = genome_build)
-
-  oplan <- future::plan()
-  future::plan(set_future_strategy(), workers = cores, gc = TRUE)
-  on.exit(future::plan(oplan), add = TRUE)
-
-
-  features <- c(
-    "segsize", "bp10MB", "osCN", "bpchrarm",
-    "changepoint", "copynumber"
-  )
-
-  .get_feature <- function(i) {
-    if (i == "segsize") {
-      send_info("Getting segment size...")
-      getSegsize(CN_data)
-    } else if (i == "bp10MB") {
-      send_info("Getting breakpoint count per 10 Mb...")
-      getBPnum(CN_data, chrlen)
-    } else if (i == "osCN") {
-      send_info("Getting length of chains of oscillating copy number...")
-      getOscilation(CN_data)
-    } else if (i == "bpchrarm") {
-      send_info("Getting breakpoint count per chromosome arm...")
-      getCentromereDistCounts(CN_data, centromeres)
-    } else if (i == "changepoint") {
-      send_info("Getting change-point copy number change...")
-      getChangepointCN(CN_data)
-    } else {
-      send_info("Getting copy number...")
-      getCN(CN_data)
-    }
-  }
-
-  res <- furrr::future_map(features, .get_feature,
-    .progress = TRUE, .options = furrr::furrr_options(seed = TRUE)
-  )
-  res <- res %>% setNames(features)
-  res
-}
-
-
-
 get_features_wang <- function(CN_data,
                               cores = 1,
                               genome_build = c("hg19", "hg38", "mm10"),
@@ -153,153 +104,6 @@ get_features_wang <- function(CN_data,
   res
 }
 
-# Get mixture model components --------------------------------------------
-
-get_components <- function(CN_features,
-                           seed = 123456,
-                           min_comp = 2,
-                           max_comp = 15,
-                           min_prior = 0.001,
-                           model_selection = "BIC",
-                           threshold = 0.1,
-                           nrep = 3,
-                           niter = 1000,
-                           cores = 1) {
-  flag_min <- FALSE
-  flag_max <- FALSE
-
-  if (length(min_comp) > 1) {
-    if (length(min_comp) != 6) {
-      stop("If you use more than 1 values, length must be 6, each value for corresponding feature!")
-    }
-    flag_min <- TRUE
-  }
-
-  if (length(max_comp) > 1) {
-    if (length(max_comp) != 6) {
-      stop("If you use more than 1 values, length must be 6, each value for corresponding feature!")
-    }
-    flag_max <- TRUE
-  }
-
-  dist_map <- c("norm", "pois", "pois", "pois", "norm", "norm")
-  names(dist_map) <- c("segsize", "bp10MB", "osCN", "bpchrarm", "changepoint", "copynumber")
-  apply_fitComponent <- function(CN_feature,
-                                 feature_name,
-                                 dist_map,
-                                 seed = 123456,
-                                 min_comp = 2,
-                                 max_comp = 10,
-                                 min_prior = 0.001,
-                                 model_selection = "BIC",
-                                 threshold = 0.1,
-                                 nrep = 1,
-                                 niter = 1000,
-                                 cores = 1) {
-    dat <- CN_feature$value
-    send_info("Fitting feature: ", feature_name, ".")
-    fit <-
-      fitComponent(
-        dat,
-        dist = dist_map[feature_name],
-        seed = seed,
-        model_selection = model_selection,
-        threshold = threshold,
-        min_prior = min_prior,
-        niter = niter,
-        nrep = nrep,
-        min_comp = min_comp,
-        max_comp = max_comp,
-        cores = cores
-      )
-    fit
-  }
-
-  purrr::pmap(list(
-    CN_feature = CN_features,
-    feature_name = names(CN_features),
-    min_comp = if (flag_min) min_comp else rep(min_comp, 6),
-    max_comp = if (flag_max) max_comp else rep(max_comp, 6)
-  ), apply_fitComponent,
-  seed = seed,
-  min_prior = min_prior,
-  model_selection = model_selection,
-  threshold = threshold,
-  nrep = nrep,
-  niter = niter,
-  dist_map = dist_map,
-  cores = cores
-  )
-}
-
-
-
-# Get sample-by-component matrix ------------------------------------------
-
-get_matrix <- function(CN_features,
-                       all_components = NULL,
-                       type = c("probability", "count"),
-                       cores = 1) {
-  type <- match.arg(type)
-
-  if (is.null(all_components)) {
-    send_info(
-      "More details about reference components please see {.url https://github.com/ShixiangWang/absoluteCNVdata}"
-    )
-    if (!file.exists(file.path(tempdir(), "Nat_Gen_component_parameters.rds"))) {
-      send_info(
-        "Nat_Gen_component_parameters.rds doesnot exist, will download reference components."
-      )
-      tryCatch(
-        download.file(
-          url = "https://github.com/ShixiangWang/absoluteCNVdata/raw/master/component_parameters.rds",
-          destfile = file.path(tempdir(), "Nat_Gen_component_parameters.rds")
-        ),
-        error = function(e) {
-          send_info("Bad internet from GitHub, try Gitee (may also not work).")
-          download.file(
-            url = "https://gitee.com/ShixiangWang/absoluteCNVdata/raw/master/component_parameters.rds",
-            destfile = file.path(tempdir(), "Nat_Gen_component_parameters.rds")
-          )
-        }
-      )
-    }
-    all_components <-
-      readRDS(file.path(tempdir(), "Nat_Gen_component_parameters.rds"))
-    send_warning(
-      "This reference data may only works for ovarian cancer!"
-    )
-  }
-
-  feature_orders <- c("bp10MB", "copynumber", "changepoint", "bpchrarm", "osCN", "segsize")
-  # Make sure have same order
-  CN_features <- CN_features[feature_orders]
-  all_components <- all_components[feature_orders]
-
-  oplan <- future::plan()
-  future::plan("multiprocess", workers = cores)
-  on.exit(future::plan(oplan), add = TRUE)
-
-  full_mat <- furrr::future_pmap(
-    list(
-      feature = CN_features,
-      component = all_components,
-      name = feature_orders
-    ),
-    .f = calculateSumOfEvents,
-    type = type,
-    .progress = TRUE,
-    .options = furrr::furrr_options(seed = TRUE)
-  )
-
-  full_mat <- purrr::reduce(full_mat, .f = base::cbind)
-
-  # rownames(full_mat) <- unique(CN_features[["segsize"]][, 1])
-  # full_mat[is.na(full_mat)] <- 0
-  full_mat
-}
-
-
 
 # Get copy number length profile ------------------------------------------
 
